##  Accessing the Availability Page in SAP for Me
In SAP for Me you can access detailed information on the status of all your SAP products, including SAP LeanIX. Keep track of various metrics, such as:
  * Events like incidents or maintenance
  * SLA availability graphs
  * Credit claims


  1. In SAP for Me, navigate to Systems and Provisioning Availability.
  2. From the availability overview page, navigate to, for example, the System overview for SAP LeanIX.
![Availability page in SAP for Me showing an 99.8% availability and graphs for the past 12-month availability](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioc7279a48438d4a94b7b9c7ddc92a76fd_HiRes.png)
